==> libgnomecanvasmm-1.3.11.tar.gz: libgnomecanvasmm-1.3.11/libgnomecanvas/libgnomecanvasmm.h <==
/* $Id: libgnomecanvasmm.h,v 1.4 2002/06/10 22:41:08 aholzmann Exp $ */
/* libgnomecanvasmm - a C++ wrapper for libgnomecanvas
 *
 * Copyright 1999-2001 Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LIBGNOMECANVASMM_H
#define LIBGNOMECANVASMM_H

/* libgnomecanvasmm version.  */
extern const int libgnomecanvasmm_major_version;
extern const int libgnomecanvasmm_minor_version;
extern const int libgnomecanvasmm_micro_version;

#include <gtkmm.h>

#include <libgnomecanvasmm/canvas.h>
#include <libgnomecanvasmm/canvas-property.h>
#include <libgnomecanvasmm/group.h>
#include <libgnomecanvasmm/init.h>
#include <libgnomecanvasmm/line.h>
#include <libgnomecanvasmm/ellipse.h>
#include <libgnomecanvasmm/pixbuf.h>
#include <libgnomecanvasmm/point.h>
#include <libgnomecanvasmm/rect.h>
#include <libgnomecanvasmm/rect-ellipse.h>
#include <libgnomecanvasmm/rich-text.h>
#include <libgnomecanvasmm/text.h>
#include <libgnomecanvasmm/widget.h>

#endif /* #ifndef LIBGNOMECANVASMM_H */

==> libgnomecanvasmm2.6_2.8.0.orig.tar.gz: libgnomecanvasmm-2.8.0/libgnomecanvas/libgnomecanvasmm.h <==
/* $Id: libgnomecanvasmm.h,v 1.5 2002/12/10 12:39:02 aholzmann Exp $ */
/* libgnomecanvasmm - a C++ wrapper for libgnomecanvas
 *
 * Copyright 1999-2001 Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LIBGNOMECANVASMM_H
#define LIBGNOMECANVASMM_H

/* libgnomecanvasmm version.  */
extern const int libgnomecanvasmm_major_version;
extern const int libgnomecanvasmm_minor_version;
extern const int libgnomecanvasmm_micro_version;

#include <gtkmm.h>

#include <libgnomecanvasmm/canvas.h>
#include <libgnomecanvasmm/properties.h>
#include <libgnomecanvasmm/group.h>
#include <libgnomecanvasmm/init.h>
#include <libgnomecanvasmm/line.h>
#include <libgnomecanvasmm/ellipse.h>
#include <libgnomecanvasmm/pixbuf.h>
#include <libgnomecanvasmm/point.h>
#include <libgnomecanvasmm/rect.h>
#include <libgnomecanvasmm/rect-ellipse.h>
#include <libgnomecanvasmm/rich-text.h>
#include <libgnomecanvasmm/text.h>
#include <libgnomecanvasmm/widget.h>

#endif /* #ifndef LIBGNOMECANVASMM_H */
